==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AnnotationLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var AnnotationLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AnnotationLayerDescriptionMetadata, _super);
    function AnnotationLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AnnotationLayerDescriptionMetadata.b = function (a) {
        if (AnnotationLayerDescriptionMetadata.a == null) {
            AnnotationLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AnnotationLayerDescriptionMetadata.c(AnnotationLayerDescriptionMetadata.a);
        }
        if (a.g(AnnotationLayerDescriptionMetadata.a)) {
            return;
        }
        a.s(AnnotationLayerDescriptionMetadata.a);
    };
    AnnotationLayerDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("UseIndex", "Boolean");
        a.item("UseLegend", "Boolean");
        a.item("CursorPosition", "Point");
        a.item("IsDefaultCrosshairDisabled", "Boolean");
        a.item("ShouldRenderAsOverlay", "Boolean");
    };
    AnnotationLayerDescriptionMetadata.d = function (a) {
        AnnotationLayerDescriptionMetadata.b(a);
        a.t("AnnotationLayer", AnnotationLayerDescriptionMetadata.a);
    };
    AnnotationLayerDescriptionMetadata.$t = markType(AnnotationLayerDescriptionMetadata, 'AnnotationLayerDescriptionMetadata');
    AnnotationLayerDescriptionMetadata.a = null;
    return AnnotationLayerDescriptionMetadata;
}(Base));
export { AnnotationLayerDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AnnotationLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var AnnotationLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AnnotationLayerDescriptionMetadata, _super);
    function AnnotationLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AnnotationLayerDescriptionMetadata.b = function (a) {
        if (AnnotationLayerDescriptionMetadata.a == null) {
            AnnotationLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AnnotationLayerDescriptionMetadata.c(AnnotationLayerDescriptionMetadata.a);
        }
        if (a.j(AnnotationLayerDescriptionMetadata.a)) {
            return;
        }
        a.y(AnnotationLayerDescriptionMetadata.a);
    };
    AnnotationLayerDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("UseIndex", "Boolean");
        a.item("UseLegend", "Boolean");
        a.item("CursorPosition", "Point");
        a.item("IsDefaultCrosshairDisabled", "Boolean");
        a.item("ShouldRenderAsOverlay", "Boolean");
    };
    AnnotationLayerDescriptionMetadata.d = function (a) {
        AnnotationLayerDescriptionMetadata.b(a);
        a.z("AnnotationLayer", AnnotationLayerDescriptionMetadata.a);
    };
    AnnotationLayerDescriptionMetadata.$t = markType(AnnotationLayerDescriptionMetadata, 'AnnotationLayerDescriptionMetadata');
    AnnotationLayerDescriptionMetadata.a = null;
    return AnnotationLayerDescriptionMetadata;
}(Base));
export { AnnotationLayerDescriptionMetadata };
